@@ -24,6 +24,7 @@
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <locale.h>
 
 #include "phonemgr-listener.h"
 
@@ -52,6 +53,13 @@ static char *call_statutes[] = {
 	"PHONEMGR_LISTENER_CALL_UNKNOWN"
 };
 
+static char *report_statuses[] = {
+	"PHONEMGR_LISTENER_REPORT_DELIVERED",
+	"PHONEMGR_LISTENER_REPORT_PENDING",
+	"PHONEMGR_LISTENER_REPORT_FAILED_TEMPORARY",
+	"PHONEMGR_LISTENER_REPORT_FAILED_PERMANENT"
+};
+
 static void
 call_status (PhonemgrListener *listener, PhonemgrListenerCallStatus status, const char *phone, const char *name, gpointer user_data)
 {
@@ -70,6 +78,25 @@ status (PhonemgrListener *listener, gint status, gpointer user_data)
 	g_message ("Got status %s (%d)", statuses[status], status);
 }
 
+static void
+report_status (PhonemgrListener *l, char *phone, time_t timestamp, PhonemgrListenerReportStatus status, gpointer user_data)
+{
+	g_message ("Received delivery report status %s for %s", report_statuses[status], phone);
+}
+
+static void
+network_status (PhonemgrListener *l, int mcc, int mnc, int lac, int cid)
+{
+	g_message ("Updated network: mcc: %d mnc: %d lac: %d cid: %d", mcc, mnc, lac, cid);
+}
+
+static gboolean
+send_message (PhonemgrListener *l)
+{
+	phonemgr_listener_queue_message (l, "+447736665138",
+					 "test message XXX", TRUE);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -94,14 +121,17 @@ main (int argc, char **argv)
 			  G_CALLBACK (call_status), (gpointer) listener);
 	g_signal_connect (G_OBJECT (listener), "battery",
 			  G_CALLBACK (battery), (gpointer) listener);
+	g_signal_connect (G_OBJECT (listener), "report-status",
+			  G_CALLBACK (report_status), (gpointer) listener);
+	g_signal_connect (G_OBJECT (listener), "network",
+			  G_CALLBACK (network_status), (gpointer) listener);
 
 //	if (phonemgr_listener_connect (listener, "1", &err)) {
 	if (phonemgr_listener_connect (listener, "00:12:D2:79:B7:33", &err)) {
 //	if (phonemgr_listener_connect (listener, "/dev/rfcomm0", &err)) {
 		g_message ("Connected OK");
 
-		/* phonemgr_listener_queue_message (listener, "1234567",
-				"test message XXX"); */
+		g_timeout_add_seconds (1, (GSourceFunc) send_message, listener);
 
 		loop = g_main_loop_new (NULL, FALSE);
 		g_main_loop_run (loop);
