@@ -32,6 +32,7 @@ G_BEGIN_DECLS
 
 #define PHONEMGR_DEFAULT_DRIVER "AT"
 #define PHONEMGR_DEFAULT_USB_DRIVER "6510"
+#define PHONEMGR_DEFAULT_GNAPPLET_DRIVER "gnapplet"
 #define PHONEMGR_CONDERR_STR(err) (err ? err->message : "No reason")
 
 typedef enum {
@@ -49,7 +50,8 @@ struct PhonemgrState {
 };
 
 PhonemgrConnectionType phonemgr_utils_address_is (const char *addr);
-int phonemgr_utils_get_channel (const char *device);
+int phonemgr_utils_get_serial_channel (const char *device);
+int phonemgr_utils_get_gnapplet_channel (const char *device);
 char *phonemgr_utils_write_config (const char *driver,
 				   const char *addr,
 				   int channel);
