@@ -22,6 +22,8 @@
 #include <glib/gi18n.h>
 #include <stdlib.h>
 #include <glade/glade.h>
+#include <gtk/gtk.h>
+#include <gtkspell/gtkspell.h>
 #include <time.h>
 #include <string.h>
 
@@ -90,7 +92,7 @@ get_resource (MyApp *app, char *uiresname)
 {
 	char *fname;
 
-	fname = g_build_filename ("..", "ui", uiresname, NULL);
+	fname = g_build_filename ("..", "data", uiresname, NULL);
 
 	if (g_file_test (fname, G_FILE_TEST_EXISTS) == FALSE) {
 		g_free (fname);
@@ -351,6 +353,7 @@ send_message (GtkWidget *w, GladeXML *ui)
 	GtkTextBuffer *buf;
 	GtkTextView *view;
 	EPhoneEntry *entry;
+	GtkToggleButton *delivery_report;
 	GtkDialog *dialog;
 	GtkTextIter s, e;
 	char *number;
@@ -361,13 +364,14 @@ send_message (GtkWidget *w, GladeXML *ui)
 	view = GTK_TEXT_VIEW (glade_xml_get_widget (ui, "messagebody"));
 	buf = gtk_text_view_get_buffer (view);
 	entry = E_PHONE_ENTRY (glade_xml_get_widget (ui, "recipient"));
+	delivery_report = GTK_TOGGLE_BUTTON (glade_xml_get_widget (ui, "delivery_report"));
 
 	gtk_text_buffer_get_start_iter (buf, &s);
 	gtk_text_buffer_get_end_iter (buf, &e);
 	number = e_phone_entry_get_number (entry);
-	phonemgr_listener_queue_message (app->listener,
-			number,
-			gtk_text_buffer_get_text (buf, &s, &e, FALSE));
+	phonemgr_listener_queue_message (app->listener, number,
+					 gtk_text_buffer_get_text (buf, &s, &e, FALSE),
+					 gtk_toggle_button_get_active (delivery_report));
 	g_free (number);
 
 	gtk_widget_hide (GTK_WIDGET (dialog));
@@ -376,6 +380,7 @@ send_message (GtkWidget *w, GladeXML *ui)
 void
 create_send_dialog (MyApp *app, GtkDialog *parent, const char *recip)
 {
+        GError *err = NULL;
 	GtkTextBuffer *buf;
 	GtkTextView *view;
 	GtkEntry *entry;
@@ -395,6 +400,12 @@ create_send_dialog (MyApp *app, GtkDialog *parent, const char *recip)
 	view = GTK_TEXT_VIEW (glade_xml_get_widget (ui, "messagebody"));
 	buf = gtk_text_view_get_buffer (view);
 	gtk_text_buffer_set_text (buf, "", 0);
+
+        if (!gtkspell_new_attach (view, NULL, &err)) {
+        	g_warning ("Couldn't initialise spell checking: %s", err->message);
+                g_error_free (err);
+        }
+
 	entry = GTK_ENTRY (glade_xml_get_widget (ui, "recipient"));
 	if (recip)
 		gtk_entry_set_text (entry, recip);
